@@ -178,7 +178,7 @@ class MainInterface:
         if self.rangeOn.get():
             s = int(self.firstFrame.get())
             e = int(self.lastFrame.get())
-
+            print(s, e)
             save_values(s, e)
             if e < len(frames_in) - 1:
                 load_frame(e + 1, master, self.fbox)
@@ -190,7 +190,7 @@ class MainInterface:
             save_values(s, e)
             load_frame(e+1, master, self.fbox)
 
-
+        print(df)
 
 class MainInterface2:
     def __init__(self):
@@ -402,7 +402,7 @@ def save_values(start, end):
         for i in range(start, end+1):
             for b in range(len(behaviors)):
                 df.at[i, columns[b]] = int(behaviors[b])
-
+    print(df.ix[current_frame_number])
 
 
 # Appends data to corresponding features_extracted csv and exports as new csv
